@@ -574,15 +574,37 @@ class ParaMonteSampler:
             #    #buildMode = mode
 
         if not libFound:
-            from _pmreqs import buildInstructionNote
+            if self.mpiEnabled:
+                parallelMsg = ("This happens frequently with parallel simulations and the " + newline
+                            + "most likely reason is that the user did NOT carefully follow " + newline
+                            + "the ParaMonte instructions to successfully install and define " + newline
+                            + "the variables of the MPI runtime library on their system. " + newline
+                            + "To learn these about these instructions, type the following " + newline
+                            + "in your Python session, " + newline
+                            + newline
+                            + "    import paramonte as pm" + newline
+                            + "    pm.verify()" + newline
+                            + newline
+                            + "Then, carefully follow the instructions provided to define " + newline
+                            + "the MPI runtime variables in your current Python session. " + newline
+                            + "If the error still persists, please report this issue at: " + newline
+                            )
+            else:
+                parallelMsg = "Please report this issue at:" + newline
+            if pm.platform.isWin32:
+                from _pmreqs import buildInstructionNoteWindows
+                buildMsg = buildInstructionNoteWindows
+            else:
+                from _pmreqs import buildInstructionNoteUnix
+                buildMsg = newline + newline + buildInstructionNoteUnix
             pm.abort( msg   = "Exhausted all possible ParaMonte dynamic library search" + newline
                             + "names but could not find any compatible library." + newline
                             #+ "Last search:" + newline
                             #+ newline
                             #+ "    " + libPath + newline
                             #+ newline
-                            + "It appears your ParaMonte Python interface is missing" + newline
-                            + "the dynamic libraries. Please report this issue at:" + newline
+                            + "It appears your ParaMonte library is missing some files. " + newline
+                            + parallelMsg
                             + newline
                             + "    " + pm.website.github.issues.url + newline
                             + newline
@@ -591,9 +613,8 @@ class ParaMonteSampler:
                             + "    " + pm.website.home.url + newline
                             + newline
                             + "for instructions on how to build the ParaMonte library" + newline
-                            + "object files on your system." + newline
-                            + newline
-                            + buildInstructionNote
+                            + "object files on your system."
+                            + buildMsg
                     , methodName = self._methodName
                     , marginTop = 1
                     , marginBot = 1
