@@ -9,30 +9,30 @@
 ####
 ####   This file is part of the ParaMonte library.
 ####
-####   Permission is hereby granted, free of charge, to any person obtaining a 
-####   copy of this software and associated documentation files (the "Software"), 
-####   to deal in the Software without restriction, including without limitation 
-####   the rights to use, copy, modify, merge, publish, distribute, sublicense, 
-####   and/or sell copies of the Software, and to permit persons to whom the 
+####   Permission is hereby granted, free of charge, to any person obtaining a
+####   copy of this software and associated documentation files (the "Software"),
+####   to deal in the Software without restriction, including without limitation
+####   the rights to use, copy, modify, merge, publish, distribute, sublicense,
+####   and/or sell copies of the Software, and to permit persons to whom the
 ####   Software is furnished to do so, subject to the following conditions:
 ####
-####   The above copyright notice and this permission notice shall be 
+####   The above copyright notice and this permission notice shall be
 ####   included in all copies or substantial portions of the Software.
 ####
-####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, 
-####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
-####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
-####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, 
-####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR 
-####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE 
+####   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+####   EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+####   MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+####   IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
+####   DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
+####   OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
 ####   OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 ####
 ####   ACKNOWLEDGMENT
 ####
 ####   ParaMonte is an honor-ware and its currency is acknowledgment and citations.
-####   As per the ParaMonte library license agreement terms, if you use any parts of 
-####   this library for any purposes, kindly acknowledge the use of ParaMonte in your 
-####   work (education/research/industry/development/...) by citing the ParaMonte 
+####   As per the ParaMonte library license agreement terms, if you use any parts of
+####   this library for any purposes, kindly acknowledge the use of ParaMonte in your
+####   work (education/research/industry/development/...) by citing the ParaMonte
 ####   library as described on this page:
 ####
 ####       https://github.com/cdslaborg/paramonte/blob/master/ACKNOWLEDGMENT.md
@@ -64,11 +64,11 @@ class TabularFileContents(OutputFileContents):
     This is the **TabularFileContents** class for generating instances
     of the ParaMonte tabular output contents. This class is NOT meant to
     be directly accessed by the ParaMonte library users. It is internally
-    used by the ParaMonte library to parse the tabular contents of the 
-    output files generated by the ParaMonte sampler routines. For example, 
-    the ParaDRAM sampler class makes calls to this class via its 
-    ``readSample()`` or ``readChain()`` or ``readMarkovChain()`` 
-    or ``readProgress()`` methods to return a list of objects 
+    used by the ParaMonte library to parse the tabular contents of the
+    output files generated by the ParaMonte sampler routines. For example,
+    the ParaDRAM sampler class makes calls to this class via its
+    ``readSample()`` or ``readChain()`` or ``readMarkovChain()``
+    or ``readProgress()`` methods to return a list of objects
     of class ``TabularFileContents``.
 
         **Parameters**
@@ -102,7 +102,7 @@ class TabularFileContents(OutputFileContents):
             reportEnabled
 
                 A logical input parameter indicating whether the ParaMonte
-                automatic guidelines to the standard output should be provided 
+                automatic guidelines to the standard output should be provided
                 or not. The default value is ``True``.
 
         **Attributes**
@@ -129,7 +129,7 @@ class TabularFileContents(OutputFileContents):
 
             plot
 
-                A structure containing the graphics tools for the 
+                A structure containing the graphics tools for the
                 visualization of the contents of the file.
 
             df
@@ -213,8 +213,8 @@ class TabularFileContents(OutputFileContents):
             self._offset = list(self.df.columns).index(self._sampleLogFuncColName) + 1 # index of the first variable
             self.ndim = len(self.df.columns) - self._offset
 
-        self.count  = len(self.df.iloc[:,1])
-        self.ncol  = len(self.df.iloc[1,:])
+        self.count = len(self.df.iloc[:,1])
+        self.ncol = len(self.df.iloc[1,:])
 
         if markovChainRequested:
 
@@ -276,8 +276,6 @@ class TabularFileContents(OutputFileContents):
 
             #### add chain autocorrelation
 
-            self.stats.maxLogFunc = getMaxLogFunc(dataFrame = self.df)
-
             self._progress.note( msg = "computing the sample autocorrelations... ", end = newline, pre = True )
             self.stats.autocorr = AutoCorr  ( dataFrame     = self.df
                                             , columns       = range(self._offset-1,self._offset+self.ndim)
@@ -286,6 +284,10 @@ class TabularFileContents(OutputFileContents):
                                             )
             self.stats.autocorr()
 
+            #### add chain maxLogFunc
+
+            self.stats.maxLogFunc = getMaxLogFunc(dataFrame = self.df)
+
         ############################################################################################################################
         #### graphics
         ############################################################################################################################
@@ -294,12 +296,12 @@ class TabularFileContents(OutputFileContents):
                                 , "scatter"
                                 , "lineScatter"
                                 ]
-        
+
         if not self._isProgressFile: self._plotTypeList +=  [ "line3"
                                                             , "scatter3"
                                                             , "lineScatter3"
                                                             , "jointplot"
-                                                            , "distplot"
+                                                            , "histplot"
                                                             , "kdeplot1"
                                                             , "kdeplot2"
                                                             , "contour3"
@@ -311,7 +313,6 @@ class TabularFileContents(OutputFileContents):
         self._progress.note( msg = "adding the graphics tools... ", end = newline, pre = True )
         self.plot = Struct()
         self._resetPlot(resetType="hard")
-
         self.plot.reset = self._resetPlot
         #self.plot.helpme = self.helpme
 
@@ -341,8 +342,8 @@ class TabularFileContents(OutputFileContents):
 
                 plotNames (optional)
 
-                    An optional string value or list of string values representing 
-                    the names of plots to reset. If no value is provided, 
+                    An optional string value or list of string values representing
+                    the names of plots to reset. If no value is provided,
                     then all plots will be reset.
 
             **Returns**
@@ -404,7 +405,7 @@ class TabularFileContents(OutputFileContents):
             isScatter   = "scatter"     in requestedPlotTypeLower
 
             isJointplot = "jointplot"   in requestedPlotTypeLower
-            isDistplot  = "distplot"    in requestedPlotTypeLower
+            isHistplot  = "histplot"    in requestedPlotTypeLower
             isKdeplot1  = "kdeplot1"    in requestedPlotTypeLower
             isKdeplot2  = "kdeplot2"    in requestedPlotTypeLower
             isContourf  = "contourf"    in requestedPlotTypeLower
@@ -414,7 +415,7 @@ class TabularFileContents(OutputFileContents):
             isGridPlot  = "grid"        in requestedPlotTypeLower
 
             isLineScatterPlot = isLine or isScatter
-            isDensityPlot = isJointplot or isDistplot or isKdeplot1 or isKdeplot2 or isContourf or isContour3 or isContour
+            isDensityPlot = isJointplot or isHistplot or isKdeplot1 or isKdeplot2 or isContourf or isContour3 or isContour
 
             if not resetTypeIsHard:
                 plotComponent = getattr(self, "plot")
@@ -460,7 +461,7 @@ class TabularFileContents(OutputFileContents):
                         plotObject.plot.enabled = False
 
             ########################################################################################################################
-            #### reset density plots: kdeplot / distplot / jointplot / contour / contourf / contour3
+            #### reset density plots: kdeplot / histplot / jointplot / contour / contourf / contour3
             ########################################################################################################################
 
             if isDensityPlot:
@@ -474,7 +475,7 @@ class TabularFileContents(OutputFileContents):
                                             )
 
                 plotObject.xcolumns = self.df.columns[self._offset]
-                if not (isDistplot or isKdeplot1):
+                if not (isHistplot or isKdeplot1):
                     if self.ndim==1:
                         plotObject.xcolumns = self.df.columns[self._offset-1]
                         plotObject.ycolumns = self.df.columns[self._offset]
@@ -500,7 +501,7 @@ class TabularFileContents(OutputFileContents):
                 plotObject.ccolumn = self._sampleLogFuncColName
 
             ########################################################################################################################
-            ## reset target component
+            #### reset target component
             ########################################################################################################################
 
             if (isLineScatterPlot or isDensityPlot) and not (plotObject._type.is3d or self._isProgressFile):
@@ -530,7 +531,7 @@ class TabularFileContents(OutputFileContents):
                             , plotNames
                             ):
 
-        pm.abort( msg   = "The input argument plotNames must be a string representing" + newline
+        pm.abort( msg   = "The input argument ``plotNames`` must be a string representing" + newline
                         + "the name of a plot belonging to the TabularFileContents class or," + newline
                         + "a list of such plot names. You have entered: " + plotNames + newline
                         + "Possible plots are: " + newline
