@@ -47,7 +47,6 @@ import weakref as wref
 from copy import deepcopy as dcopy
 
 import _paramonte as pm
-from paramonte.vis.Target import Target
 from paramonte.vis._BasePlot import BasePlot
 from paramonte.vis.LineScatterPlot import LineScatterPlot
 from paramonte.vis.DensityPlot import DensityPlot
@@ -417,8 +416,8 @@ class GridPlot(BasePlot):
 
         self.plotType.diag = Struct()
         self.plotType.diag.enabled = True
-        self.plotType.diag.value = "distplot"
-        self.plotType.diag.names = ["distplot"]
+        self.plotType.diag.value = "histplot"
+        self.plotType.diag.names = ["histplot"]
 
         self.plotType.upper = Struct()
         self.plotType.upper.enabled = True
@@ -480,16 +479,28 @@ class GridPlot(BasePlot):
         template.contourf.kws.alpha = 1
         template.contourf.kws.levels = 50
 
-        # distplot
+        # histplot
 
-        template.distplot = Struct()
-        template.distplot.enabled = True
-        template.distplot.kws = Struct()
-        template.distplot.kws.kde = False
-        template.distplot.kws.hist_kws = dict()
-        template.distplot.kws.hist_kws["linewidth"] = 0
-        template.distplot.kws.hist_kws["histtype"] = "stepfilled"
-        template.distplot.kws.hist_kws["density"] = template.distplot.kws.kde
+        template.histplot = Struct()
+        template.histplot.enabled = True
+        template.histplot.kws = Struct()
+        template.histplot.kws.kde = False
+        template.histplot.kws.bins = "auto"
+        template.histplot.kws.stat = "count"
+        template.histplot.kws.kde_kws = dict()
+        template.histplot.kws.binwidth = None
+        template.histplot.kws.binrange = None
+        template.histplot.kws.multiple = "stack"
+        template.histplot.kws.element = "step"
+        template.histplot.kws.legend = False
+        template.histplot.kws.shrink = 1
+        template.histplot.kws.color = None
+        template.histplot.kws.fill = True
+        template.histplot.kws.common_norm = True
+        template.histplot.kws.common_bins = False
+        template.histplot.kws.line_kws = dict()
+        template.histplot.kws.line_kws["linewidth"] = 0
+        template.histplot.kws.line_kws["linestyle"] = "-"
 
         # legend template
 
@@ -558,11 +569,11 @@ class GridPlot(BasePlot):
         self.layout.contourf.limits             = None
         self.layout.contourf.gridSize           = 512
 
-        self.layout.distplot                    = Struct()
-        self.layout.distplot.figure             = dcopy(template.figure)
-        self.layout.distplot.distplot           = dcopy(template.distplot)
-        self.layout.distplot.legend             = dcopy(template.legend)
-        #self.layout.distplot.target             = dcopy(template.target)
+        self.layout.histplot                    = Struct()
+        self.layout.histplot.figure             = dcopy(template.figure)
+        self.layout.histplot.histplot           = dcopy(template.histplot)
+        self.layout.histplot.legend             = dcopy(template.legend)
+        #self.layout.histplot.target             = dcopy(template.target)
 
         self.layout.line                        = Struct()
         self.layout.line.figure                 = dcopy(template.figure)
@@ -807,7 +818,7 @@ class GridPlot(BasePlot):
         if self.plotType.diag.enabled:
             #self._progress.note( msg = "generating diagonal subplots... ", end = "" )
             self._progress.timer.toc()
-            self.currentFig.pairgrid.map_diag( sns.distplot, **vars(self.layout.distplot.distplot.kws) )
+            self.currentFig.pairgrid.map_diag( sns.histplot, **vars(self.layout.histplot.histplot.kws) )
             self._progress.timer.toc()
             avgDiagTime = self._progress.timer.delta / self._nrow
             #if self._reportEnabled:
@@ -837,7 +848,7 @@ class GridPlot(BasePlot):
                 
                     plotEnabled = True
                     requestedPlotType = self.plotType.diag.value
-                    if self.plotType.diag.value=="distplot": RequestedPlotClass = DensityPlot
+                    if self.plotType.diag.value=="histplot": RequestedPlotClass = DensityPlot
 
                 if icol>irow and self.plotType.upper.enabled:
 
@@ -948,45 +959,45 @@ class GridPlot(BasePlot):
             if mappable is None and self.plotType.upper.enabled:
 
                 if mappable is None and "scatter" in self.plotType.upper.value.lower():
-                    mappable = self.currentFig.subplotGrid[0][1].currentFig.scatter
+                    mappable = self.currentFig.subplotGrid[0][1].currentFig.scatterList[0]
 
                 if mappable is None and "line"==self.plotType.upper.value and self.layout.line.lineCollection.enabled:
-                    mappable = self.currentFig.subplotGrid[0][1].currentFig.lineCollection
+                    mappable = self.currentFig.subplotGrid[0][1].currentFig.lineCollectionList[0]
 
                 if mappable is None and "lineScatter"==self.plotType.upper.value and self.layout.lineScatter.lineCollection.enabled:
-                    mappable = self.currentFig.subplotGrid[0][1].currentFig.lineCollection
+                    mappable = self.currentFig.subplotGrid[0][1].currentFig.lineCollectionList[0]
 
             if mappable is None and self.plotType.lower.enabled:
 
                 if mappable is None and "scatter" in self.plotType.lower.value.lower():
-                    mappable = self.currentFig.subplotGrid[1][0].currentFig.scatter
+                    mappable = self.currentFig.subplotGrid[1][0].currentFig.scatterList[0]
 
                 if mappable is None and "line"==self.plotType.upper.value and self.layout.line.lineCollection.enabled:
-                    mappable = self.currentFig.subplotGrid[1][0].currentFig.lineCollection
+                    mappable = self.currentFig.subplotGrid[1][0].currentFig.lineCollectionList[0]
 
                 if mappable is None and "lineScatter"==self.plotType.upper.value and self.layout.lineScatter.lineCollection.enabled:
-                    mappable = self.currentFig.subplotGrid[1][0].currentFig.lineCollection
+                    mappable = self.currentFig.subplotGrid[1][0].currentFig.lineCollectionList[0]
 
             # search for contour mappable
 
             if mappable is None and self.plotType.upper.enabled:
 
                 if mappable is None and "contour"==self.plotType.upper.value.lower():
-                    mappable = self.currentFig.subplotGrid[0][1].currentFig.contour
+                    mappable = self.currentFig.subplotGrid[0][1].currentFig.contourList[0]
                     isDensityMappable = True
 
                 if mappable is None and "contourf" in self.plotType.upper.value.lower():
-                    mappable = self.currentFig.subplotGrid[0][1].currentFig.contourf
+                    mappable = self.currentFig.subplotGrid[0][1].currentFig.contourfList[0]
                     isDensityMappable = True
 
             if mappable is None and self.plotType.lower.enabled:
 
                 if mappable is None and "contour"==self.plotType.lower.value.lower():
-                    mappable = self.currentFig.subplotGrid[1][0].currentFig.contour
+                    mappable = self.currentFig.subplotGrid[1][0].currentFig.contourList[0]
                     isDensityMappable = True
 
                 if mappable is None and "contourf" in self.plotType.lower.value.lower():
-                    mappable = self.currentFig.subplotGrid[1][0].currentFig.contourf
+                    mappable = self.currentFig.subplotGrid[1][0].currentFig.contourfList[0]
                     isDensityMappable = True
 
             # add colorbar
